adminpb

package
v0.0.0-...-7334d01 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	AdminReasonerService_ListReasoners_FullMethodName = "/admin.v1.AdminReasonerService/ListReasoners"
)

Variables

var AdminReasonerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "admin.v1.AdminReasonerService",
	HandlerType: (*AdminReasonerServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ListReasoners",
			Handler:    _AdminReasonerService_ListReasoners_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/admin/reasoner_admin.proto",
}

AdminReasonerService_ServiceDesc is the grpc.ServiceDesc for AdminReasonerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_admin_reasoner_admin_proto protoreflect.FileDescriptor

Functions

func RegisterAdminReasonerServiceServer

func RegisterAdminReasonerServiceServer(s grpc.ServiceRegistrar, srv AdminReasonerServiceServer)

Types

type AdminReasonerServiceClient

type AdminReasonerServiceClient interface {
	// ListReasoners returns the set of registered reasoners and their parent nodes.
	ListReasoners(ctx context.Context, in *ListReasonersRequest, opts ...grpc.CallOption) (*ListReasonersResponse, error)
}

AdminReasonerServiceClient is the client API for AdminReasonerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

AdminReasonerService exposes control-surface operations for reasoning components.

type AdminReasonerServiceServer

type AdminReasonerServiceServer interface {
	// ListReasoners returns the set of registered reasoners and their parent nodes.
	ListReasoners(context.Context, *ListReasonersRequest) (*ListReasonersResponse, error)
	// contains filtered or unexported methods
}

AdminReasonerServiceServer is the server API for AdminReasonerService service. All implementations must embed UnimplementedAdminReasonerServiceServer for forward compatibility.

AdminReasonerService exposes control-surface operations for reasoning components.

type ListReasonersRequest

type ListReasonersRequest struct {
	// contains filtered or unexported fields
}

func (*ListReasonersRequest) Descriptor deprecated

func (*ListReasonersRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListReasonersRequest.ProtoReflect.Descriptor instead.

func (*ListReasonersRequest) ProtoMessage

func (*ListReasonersRequest) ProtoMessage()

func (*ListReasonersRequest) ProtoReflect

func (x *ListReasonersRequest) ProtoReflect() protoreflect.Message

func (*ListReasonersRequest) Reset

func (x *ListReasonersRequest) Reset()

func (*ListReasonersRequest) String

func (x *ListReasonersRequest) String() string

type ListReasonersResponse

type ListReasonersResponse struct {
	Reasoners []*Reasoner `protobuf:"bytes,1,rep,name=reasoners,proto3" json:"reasoners,omitempty"`
	// contains filtered or unexported fields
}

func (*ListReasonersResponse) Descriptor deprecated

func (*ListReasonersResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListReasonersResponse.ProtoReflect.Descriptor instead.

func (*ListReasonersResponse) GetReasoners

func (x *ListReasonersResponse) GetReasoners() []*Reasoner

func (*ListReasonersResponse) ProtoMessage

func (*ListReasonersResponse) ProtoMessage()

func (*ListReasonersResponse) ProtoReflect

func (x *ListReasonersResponse) ProtoReflect() protoreflect.Message

func (*ListReasonersResponse) Reset

func (x *ListReasonersResponse) Reset()

func (*ListReasonersResponse) String

func (x *ListReasonersResponse) String() string

type Reasoner

type Reasoner struct {
	ReasonerId    string `protobuf:"bytes,1,opt,name=reasoner_id,json=reasonerId,proto3" json:"reasoner_id,omitempty"`
	AgentNodeId   string `protobuf:"bytes,2,opt,name=agent_node_id,json=agentNodeId,proto3" json:"agent_node_id,omitempty"`
	Name          string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	Description   string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
	Status        string `protobuf:"bytes,5,opt,name=status,proto3" json:"status,omitempty"`
	NodeVersion   string `protobuf:"bytes,6,opt,name=node_version,json=nodeVersion,proto3" json:"node_version,omitempty"`
	LastHeartbeat string `protobuf:"bytes,7,opt,name=last_heartbeat,json=lastHeartbeat,proto3" json:"last_heartbeat,omitempty"`
	// contains filtered or unexported fields
}

func (*Reasoner) Descriptor deprecated

func (*Reasoner) Descriptor() ([]byte, []int)

Deprecated: Use Reasoner.ProtoReflect.Descriptor instead.

func (*Reasoner) GetAgentNodeId

func (x *Reasoner) GetAgentNodeId() string

func (*Reasoner) GetDescription

func (x *Reasoner) GetDescription() string

func (*Reasoner) GetLastHeartbeat

func (x *Reasoner) GetLastHeartbeat() string

func (*Reasoner) GetName

func (x *Reasoner) GetName() string

func (*Reasoner) GetNodeVersion

func (x *Reasoner) GetNodeVersion() string

func (*Reasoner) GetReasonerId

func (x *Reasoner) GetReasonerId() string

func (*Reasoner) GetStatus

func (x *Reasoner) GetStatus() string

func (*Reasoner) ProtoMessage

func (*Reasoner) ProtoMessage()

func (*Reasoner) ProtoReflect

func (x *Reasoner) ProtoReflect() protoreflect.Message

func (*Reasoner) Reset

func (x *Reasoner) Reset()

func (*Reasoner) String

func (x *Reasoner) String() string

type UnimplementedAdminReasonerServiceServer

type UnimplementedAdminReasonerServiceServer struct{}

UnimplementedAdminReasonerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAdminReasonerServiceServer) ListReasoners

type UnsafeAdminReasonerServiceServer

type UnsafeAdminReasonerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAdminReasonerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AdminReasonerServiceServer will result in compilation errors.

Jump to